Module subprocess

Module subprocess 

Structs

RunOutput

Enums

Arg
A command-line argument that may or may not contain sensitive data.
SubprocessError

Functions

run
Run a subprocess, passing all arguments as plain (non-sensitive) strings.
run_args
Run a subprocess with typed arguments that distinguish sensitive values.